@@ -39,7 +39,7 @@ from .urls_patterns import URL_ADMIN_SERVER_INFO, URL_ADMIN_CLIENT_AUTHZ_RESOURC
     URL_ADMIN_GROUP_MEMBERS, URL_ADMIN_USER_STORAGE, URL_ADMIN_GROUP_PERMISSIONS, URL_ADMIN_IDPS, \
     URL_ADMIN_USER_CLIENT_ROLES_AVAILABLE, URL_ADMIN_USERS, URL_ADMIN_CLIENT_AUTHZ_RESOURCES_ID, URL_ADMIN_CLIENT_AUTHZ_POLICIES, \
     URL_ADMIN_CLIENT_AUTHZ_POLICIES_ID, URL_ADMIN_CLIENT_AUTHZ_PERMISSIONS, URL_ADMIN_CLIENT_AUTHZ_PERMISSIONS_ID, \
-    URL_ADMIN_USER_CLIENT_ROLES_COMPOSITE_ID, URL_ADMIN_GROUP_CLIENT_ROLES
+    URL_ADMIN_USER_CLIENT_ROLES_COMPOSITE_ID, URL_ADMIN_GROUP_CLIENT_ROLES, USE_ADMIN_CLIENT_AUTHZ_POLICIES_EVAL 
 
 def serialize(obj):
     """JSON serializer for objects not serializable by default json code"""
@@ -411,6 +411,8 @@ class KeycloakAdmin:
 
         :return: array GroupRepresentation
         """
+        if not query:
+            query = {}
         params_path = {"realm-name": self.realm_name}
         data_raw = self.connection.raw_get(URL_ADMIN_GROUPS.format(**params_path), **query)
         return raise_error_from_response(data_raw, KeycloakGetError)
@@ -538,7 +540,7 @@ class KeycloakAdmin:
             data_raw = self.connection.raw_post(URL_ADMIN_GROUPS.format(**params_path),
                                                 data=json.dumps(payload))
         else:
-            params_path = {"realm-name": self.realm_name, "id": parent, }
+            params_path = {"realm-name": self.realm_name, "id": parent}
             data_raw = self.connection.raw_post(URL_ADMIN_GROUP_CHILD.format(**params_path),
                                                 data=json.dumps(payload))
         return raise_error_from_response(data_raw, KeycloakGetError, expected_code=201, skip_exists=skip_exists)
@@ -699,7 +701,7 @@ class KeycloakAdmin:
         data_raw = self.connection.raw_get(URL_ADMIN_CLIENT_AUTHZ_SETTINGS.format(**params_path))
         return data_raw
 
-    def get_client_authz_resources(self, client_id):
+    def get_client_authz_resources(self, client_id, query):
         """
         Get resources from client.
 
@@ -709,7 +711,7 @@ class KeycloakAdmin:
         """
 
         params_path = {"realm-name": self.realm_name, "id": client_id}
-        data_raw = self.connection.raw_get(URL_ADMIN_CLIENT_AUTHZ_RESOURCES.format(**params_path))
+        data_raw = self.connection.raw_get(URL_ADMIN_CLIENT_AUTHZ_RESOURCES.format(**params_path), **query)
         return raise_error_from_response(data_raw, KeycloakGetError)
 
     def create_client_authz_resource(self, client_id, payload):
@@ -1119,3 +1121,20 @@ class KeycloakAdmin:
         data_raw = self.connection.raw_post(URL_ADMIN_USER_STORAGE.format(**params_path),
                                             data=json.dumps(data), **params_query)
         return raise_error_from_response(data_raw, KeycloakGetError)
+
+    def evaluate(self, client_id, user_id, resource_name):
+        """
+        Evaluate permissions on resources.
+
+        :param client_id: id of client (not client-id)
+        :param user_id: id of user
+        :param resource_name: name of resource (type)
+        :return: the list of resources with applied permissions
+        """
+        payload = {"resources":[{"type":resource_name}],
+                                "clientId":client_id,
+                                "userId":user_id};
+        params_path = {"realm-name": self.realm_name, "id": client_id}
+        data_raw = self.connection.raw_post(USE_ADMIN_CLIENT_AUTHZ_POLICIES_EVAL.format(**params_path),
+                                              data=json.dumps(payload, default=serialize))
+        return raise_error_from_response(data_raw, KeycloakGetError, expected_code=200)
